@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 30 Mar 2013
  *
- * Copyright (C) 2013-2018  Urs Fleisch
+ * Copyright (C) 2013-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -25,8 +25,10 @@
  */
 
 #include "kdeplatformtools.h"
+#include <QCoreApplication>
 #include <QtConfig>
 #include <kconfig_version.h>
+#include <kwidgetsaddons_version.h>
 #include <KMessageBox>
 #include <KSharedConfig>
 #include <KIO/CopyJob>
@@ -40,8 +42,7 @@
  * Constructor.
  */
 KdePlatformTools::KdePlatformTools()
-{
-}
+{}
 
 /**
  * Destructor.
@@ -104,7 +105,7 @@ QString KdePlatformTools::readFromClipboard() const
  * @return audio player, nullptr if not supported.
  */
 QObject* KdePlatformTools::createAudioPlayer(Kid3Application* app,
-                                   bool dbusEnabled) const
+                                             bool dbusEnabled) const
 {
   return GuiPlatformTools::createAudioPlayer(app, dbusEnabled);
 }
@@ -189,10 +190,26 @@ void KdePlatformTools::errorList(QWidget* parent, const QString& text,
  * @return QMessageBox::Yes, QMessageBox::No or QMessageBox::Cancel.
  */
 int KdePlatformTools::warningYesNoCancel(QWidget* parent, const QString& text,
-    const QString& caption)
+                                         const QString& caption)
 {
-  int rc = KMessageBox::warningYesNoCancel(parent, text, caption);
-  switch (rc) {
+#if KWIDGETSADDONS_VERSION >= 0x05f000
+switch (KMessageBox::warningTwoActionsCancel(parent, text, caption,
+          KGuiItem(QCoreApplication::translate("@default", "&Yes")),
+          KGuiItem(QCoreApplication::translate("@default", "&No")))) {
+  case KMessageBox::Ok:
+    return QMessageBox::Ok;
+  case KMessageBox::Cancel:
+    return QMessageBox::Cancel;
+  case KMessageBox::PrimaryAction:
+    return QMessageBox::Yes;
+  case KMessageBox::SecondaryAction:
+    return QMessageBox::No;
+  case KMessageBox::Continue:
+  default:
+    return QMessageBox::Ignore;
+  }
+#else
+  switch (KMessageBox::warningYesNoCancel(parent, text, caption)) {
   case KMessageBox::Ok:
     return QMessageBox::Ok;
   case KMessageBox::Cancel:
@@ -205,6 +222,7 @@ int KdePlatformTools::warningYesNoCancel(QWidget* parent, const QString& text,
   default:
     return QMessageBox::Ignore;
   }
+#endif
 }
 
 /**
@@ -218,14 +236,25 @@ int KdePlatformTools::warningYesNoCancel(QWidget* parent, const QString& text,
 int KdePlatformTools::warningYesNoList(QWidget* parent, const QString& text,
     const QStringList& strlist, const QString& caption)
 {
-  int rc = KMessageBox::warningYesNoList(parent, text, strlist, caption);
-  switch (rc) {
+#if KWIDGETSADDONS_VERSION >= 0x05f000
+  switch (KMessageBox::warningTwoActionsList(parent, text, strlist, caption,
+            KGuiItem(QCoreApplication::translate("@default", "&Yes")),
+            KGuiItem(QCoreApplication::translate("@default", "&No")))) {
+  case KMessageBox::PrimaryAction:
+    return QMessageBox::Yes;
+  case KMessageBox::SecondaryAction:
+  default:
+    return QMessageBox::No;
+  }
+#else
+  switch (KMessageBox::warningYesNoList(parent, text, strlist, caption)) {
   case KMessageBox::Yes:
     return QMessageBox::Yes;
   case KMessageBox::No:
   default:
     return QMessageBox::No;
   }
+#endif
 }
 
 /**
