@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Jun 2013
  *
- * Copyright (C) 2013-2018  Urs Fleisch
+ * Copyright (C) 2013-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -87,6 +87,18 @@ class KID3_CORE_EXPORT GuiConfig : public StoredConfig<GuiConfig> {
   /** true to play file on double click */
   Q_PROPERTY(bool playOnDoubleClick READ playOnDoubleClick
              WRITE setPlayOnDoubleClick NOTIFY playOnDoubleClickChanged)
+  /** true to select file on play */
+  Q_PROPERTY(bool selectFileOnPlayEnabled READ selectFileOnPlayEnabled
+             WRITE setSelectFileOnPlayEnabled NOTIFY selectFileOnPlayEnabledChanged)
+  /** true if play tool bar is visible */
+  Q_PROPERTY(bool playToolBarVisible READ playToolBarVisible
+             WRITE setPlayToolBarVisible NOTIFY playToolBarVisibleChanged)
+  /** preferred audio output description and ID */
+  Q_PROPERTY(QString preferredAudioOutput READ preferredAudioOutput
+             WRITE setPreferredAudioOutput NOTIFY preferredAudioOutputChanged)
+  /** play tool bar docked area */
+  Q_PROPERTY(int playToolBarArea READ playToolBarArea
+             WRITE setPlayToolBarArea NOTIFY playToolBarAreaChanged)
   /** config window geometry */
   Q_PROPERTY(QByteArray configWindowGeometry READ configWindowGeometry
              WRITE setConfigWindowGeometry NOTIFY configWindowGeometryChanged)
@@ -100,21 +112,21 @@ public:
   /**
    * Destructor.
    */
-  virtual ~GuiConfig() override = default;
+  ~GuiConfig() override = default;
 
   /**
    * Persist configuration.
    *
    * @param config configuration
    */
-  virtual void writeToConfig(ISettings* config) const override;
+  void writeToConfig(ISettings* config) const override;
 
   /**
    * Read persisted configuration.
    *
    * @param config configuration
    */
-  virtual void readFromConfig(ISettings* config) override;
+  void readFromConfig(ISettings* config) override;
 
   /** Get sorted column in file list. */
   int fileListSortColumn() const { return m_fileListSortColumn; }
@@ -222,6 +234,30 @@ public:
   /** Set if play file on double click is enabled. */
   void setPlayOnDoubleClick(bool playOnDoubleClick);
 
+  /** Check if select file on play is enabled. */
+  bool selectFileOnPlayEnabled() const { return m_selectFileOnPlayEnabled; }
+
+  /** Enable select file on play. */
+  void setSelectFileOnPlayEnabled(bool selectFileOnPlayEnabled);
+
+  /** Check if play tool bar is visible. */
+  bool playToolBarVisible() const { return m_playToolBarVisible; }
+
+  /** Set if play tool bar is visible. */
+  void setPlayToolBarVisible(bool playToolBarVisible);
+
+  /** Get name and ID of preferred audio output. */
+  QString preferredAudioOutput() const { return m_preferredAudioOutput; }
+
+  /** Set name and ID of preferred audio output. */
+  void setPreferredAudioOutput(const QString& preferredAudioOutput);
+
+  /** Get play tool bar docked area. */
+  int playToolBarArea() const { return m_playToolBarArea; }
+
+  /** Set play tool bar docked area. */
+  void setPlayToolBarArea(int playToolBarArea);
+
   /** Get config window geometry. */
   QByteArray configWindowGeometry() const { return m_configWindowGeometry; }
 
@@ -280,6 +316,18 @@ signals:
   /** Emitted when @a playOnDoubleClick changed. */
   void playOnDoubleClickChanged(bool playOnDoubleClick);
 
+  /** Emitted when @a selectFileOnPlayEnabled changed. */
+  void selectFileOnPlayEnabledChanged(bool selectFileOnPlayEnabled);
+
+  /** Emitted when @a playToolBarVisible changed. */
+  void playToolBarVisibleChanged(bool playToolBarVisible);
+
+  /** Emitted when @a preferredAudioOutput changed. */
+  void preferredAudioOutputChanged(const QString& preferredAudioOutput);
+
+  /** Emitted when @a playToolBarArea changed. */
+  void playToolBarAreaChanged(int playToolBarArea);
+
   /** Emitted when @a configWindowGeometry changed. */
   void configWindowGeometryChanged(const QByteArray& configWindowGeometry);
 
@@ -297,11 +345,15 @@ private:
   QList<int> m_splitterSizes;
   QList<int> m_vSplitterSizes;
   QByteArray m_configWindowGeometry;
+  QString m_preferredAudioOutput;
+  int m_playToolBarArea;
   bool m_autoHideTags;
   bool m_hideFile;
   bool m_hideTag[Frame::Tag_NumValues];
   bool m_hidePicture;
   bool m_playOnDoubleClick;
+  bool m_selectFileOnPlayEnabled;
+  bool m_playToolBarVisible;
   bool m_fileListCustomColumnWidthsEnabled;
   bool m_dirListCustomColumnWidthsEnabled;
 
