@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Dec 2012
  *
- * Copyright (C) 2012  Urs Fleisch
+ * Copyright (C) 2012-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef CHECKABLESTRINGLISTMODEL_H
-#define CHECKABLESTRINGLISTMODEL_H
+#pragma once
 
 #include <QStringListModel>
 #include "kid3api.h"
@@ -41,19 +40,19 @@ public:
    * Constructor.
    * @param parent parent widget
    */
-  explicit CheckableStringListModel(QObject* parent = 0);
+  explicit CheckableStringListModel(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~CheckableStringListModel();
+  ~CheckableStringListModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const;
+  Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -61,8 +60,8 @@ public:
    * @param role item data role
    * @return data for role
    */
-  virtual QVariant data(const QModelIndex& index,
-                        int role = Qt::DisplayRole) const;
+  QVariant data(const QModelIndex& index,
+                int role = Qt::DisplayRole) const override;
   /**
    * Set data for a given role.
    * @param index model index
@@ -70,8 +69,8 @@ public:
    * @param role item data role
    * @return true if successful
    */
-  virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role = Qt::EditRole);
+  bool setData(const QModelIndex& index, const QVariant& value,
+               int role = Qt::EditRole) override;
 
 
   /**
@@ -81,16 +80,16 @@ public:
    * @param parent parent model index
    * @return true if rows were successfully inserted.
    */
-  virtual bool insertRows(int row, int count, const QModelIndex& parent = QModelIndex());
+  bool insertRows(int row, int count, const QModelIndex& parent = QModelIndex()) override;
 
   /**
-   * removeRows
+   * Remove rows.
    * @param row first row
    * @param count number of rows to remove
    * @param parent parent model index
    * @return true if rows were successfully removed.
    */
-  virtual bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex());
+  bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Set mask with checked state for the items in the model.
@@ -109,5 +108,3 @@ public:
 private:
   quint64 m_bitMask;
 };
-
-#endif // CHECKABLESTRINGLISTMODEL_H
