@@ -138,7 +138,7 @@ static QString translateDriveName(const QFileInfo &drive)
 FileInfoGatherer::FileInfoGatherer(QObject *parent)
     : QThread(parent), abort(false),
 #ifndef QT_NO_FILESYSTEMWATCHER
-      watcher(0),
+      watcher(nullptr),
 #endif
 #ifdef Q_OS_WIN
       m_resolveSymlinks(true),
@@ -372,10 +372,10 @@ ExtendedInformation FileInfoGatherer::getInfo(const QFileInfo &fileInfo) const
         if (!fileInfo.exists() && !fileInfo.isSymLink()) {
             watcher->removePath(fileInfo.absoluteFilePath());
         } else {
-            const QString path = fileInfo.absoluteFilePath();
-            if (!path.isEmpty() && fileInfo.exists() && fileInfo.isFile() && fileInfo.isReadable()
-                && !watcher->files().contains(path)) {
-                watcher->addPath(path);
+            if (const QString filePath = fileInfo.absoluteFilePath();
+                !filePath.isEmpty() && fileInfo.exists() && fileInfo.isFile() && fileInfo.isReadable()
+                && !watcher->files().contains(filePath)) {
+                watcher->addPath(filePath);
             }
         }
     }
