@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 01 May 2011
  *
- * Copyright (C) 2011-2018  Urs Fleisch
+ * Copyright (C) 2011-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -28,6 +28,7 @@
 
 #include <QAbstractTableModel>
 #include <QVector>
+#include <QSet>
 #include <QBitArray>
 #include "frame.h"
 #include "kid3api.h"
@@ -74,14 +75,14 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FrameTableModel() override = default;
+  ~FrameTableModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
+  Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -89,8 +90,8 @@ public:
    * @param role item data role
    * @return data for role
    */
-  virtual QVariant data(const QModelIndex& index,
-                        int role = Qt::DisplayRole) const override;
+  QVariant data(const QModelIndex& index,
+                int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for a given role.
@@ -99,8 +100,8 @@ public:
    * @param role item data role
    * @return true if successful
    */
-  virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role = Qt::EditRole) override;
+  bool setData(const QModelIndex& index, const QVariant& value,
+               int role = Qt::EditRole) override;
 
   /**
    * Get data for header section.
@@ -109,16 +110,16 @@ public:
    * @param role item data role
    * @return header data for role
    */
-  virtual QVariant headerData(int section, Qt::Orientation orientation,
-                              int role = Qt::DisplayRole) const override;
+  QVariant headerData(int section, Qt::Orientation orientation,
+                      int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for header section.
    * Not supported.
    * @return false
    */
-  virtual bool setHeaderData(int, Qt::Orientation, const QVariant&,
-                             int = Qt::EditRole) override { return false; }
+  bool setHeaderData(int, Qt::Orientation, const QVariant&,
+                     int = Qt::EditRole) override { return false; }
 
   /**
    * Get number of rows.
@@ -126,7 +127,7 @@ public:
    * @return number of rows,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+  int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get number of columns.
@@ -134,7 +135,7 @@ public:
    * @return number of columns,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+  int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Remove rows.
@@ -143,8 +144,8 @@ public:
    * @param parent parent model index, invalid for table models
    * @return true if successful
    */
-  virtual bool removeRows(int row, int count,
-                          const QModelIndex& parent = QModelIndex()) override;
+  bool removeRows(int row, int count,
+                  const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Insert rows.
@@ -154,14 +155,14 @@ public:
    * @param parent parent model index, invalid for table models
    * @return true if successful
    */
-  virtual bool insertRows(int row, int count,
-                          const QModelIndex& parent = QModelIndex()) override;
+  bool insertRows(int row, int count,
+                  const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Map role identifiers to role property names in scripting languages.
    * @return hash mapping role identifiers to names.
    */
-  virtual QHash<int,QByteArray> roleNames() const override;
+  QHash<int,QByteArray> roleNames() const override;
 
   /**
    * Insert a frame.
@@ -184,9 +185,9 @@ public:
 
   /**
    * Mark changed frames.
-   * @param frameMask mask with bits of frame types to mark
+   * @param types frame types to mark
    */
-  void markChangedFrames(quint64 frameMask);
+  void markChangedFrames(const QList<Frame::ExtendedType>& types);
 
   /**
    * Get frame for index.
@@ -332,6 +333,7 @@ private:
   QBitArray m_frameSelected;
   quint64 m_markedRows;
   quint64 m_changedFrames;
+  QSet<QString> m_changedOtherFrameNames;
   FrameCollection m_frames;
   QVector<FrameCollection::iterator> m_frameOfRow;
   QHash<Frame::ExtendedType, QSet<QString>> m_differentValues;
