@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 10 Jul 2011
  *
- * Copyright (C) 2011-2018  Urs Fleisch
+ * Copyright (C) 2011-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -140,7 +140,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~Kid3Application() override;
+  ~Kid3Application() override;
 
 #ifdef HAVE_QTDBUS
   /**
@@ -311,11 +311,6 @@ public:
    */
   Q_INVOKABLE QObject* getAudioPlayer();
 
-  /**
-   * Delete audio player.
-   */
-  void deleteAudioPlayer();
-
   /**
    * Get context for tag.
    * @param tagNr tag number
@@ -743,7 +738,7 @@ public:
    *
    * @return number of tracks, 0 if not found.
    */
-  Q_INVOKABLE int getTotalNumberOfTracksInDir();
+  Q_INVOKABLE int getTotalNumberOfTracksInDir() const;
 
   /**
    * Get name of selected file.
@@ -859,7 +854,7 @@ public:
    * pointer to a deleted object.
    * @param frameEditor frame editor
    */
-  void removeFrameEditor(IFrameEditor* frameEditor);
+  void removeFrameEditor(const IFrameEditor* frameEditor);
 
   /**
    * Get ID to get cover art image.
@@ -877,7 +872,7 @@ public:
    * Get the numbers of the selected rows in a list suitable for scripting.
    * @return list with row numbers.
    */
-  Q_INVOKABLE QVariantList getFileSelectionRows();
+  Q_INVOKABLE QVariantList getFileSelectionRows() const;
 
   /**
    * Set the file selection from a list of model indexes.
@@ -1289,6 +1284,12 @@ public slots:
   void deactivateMprisInterface();
 #endif
 
+  /**
+   * Update state when file is about to be played.
+   * @param filePath path to file
+   */
+  void onAboutToPlay(const QString& filePath);
+
   /**
    * Close the file handle of a tagged file.
    * @param filePath path to file
