@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 21 Mar 2004
  *
- * Copyright (C) 2004-2018  Urs Fleisch
+ * Copyright (C) 2004-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -140,8 +140,7 @@ void RenDirDialog::setupMainPage(QWidget* page, QVBoxLayout* vlayout)
 
   vlayout->addLayout(actionLayout);
 
-  QByteArray geometry = renDirCfg.windowGeometry();
-  if (!geometry.isEmpty()) {
+  if (QByteArray geometry = renDirCfg.windowGeometry(); !geometry.isEmpty()) {
     restoreGeometry(geometry);
   }
 }
@@ -323,8 +322,8 @@ void RenDirDialog::pageChanged()
 void RenDirDialog::editFormats()
 {
   setFormats();
-  StringListEditDialog dialog(m_formats, tr("Folder Name from Tag"), this);
-  if (dialog.exec() == QDialog::Accepted) {
+  if (StringListEditDialog dialog(m_formats, tr("Folder Name from Tag"), this);
+      dialog.exec() == QDialog::Accepted) {
     m_formats = dialog.stringList();
     setFormats();
   }
