@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 03-Aug-2011
  *
- * Copyright (C) 2011-2018  Urs Fleisch
+ * Copyright (C) 2011-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -35,6 +35,7 @@ class Kid3Application;
 class TaggedFile;
 #if QT_VERSION >= 0x060200
 class QAudioOutput;
+class QMediaDevices;
 class MediaPlaylist;
 #else
 class QMediaPlaylist;
@@ -64,7 +65,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~AudioPlayer() override = default;
+  ~AudioPlayer() override = default;
 
   /**
    * Get number of files in play list.
@@ -234,6 +235,11 @@ private slots:
    * @param status media status (QMediaPlayer::MediaStatus)
    */
   void onMediaStatusChanged(int status);
+
+  /**
+   * Set the output device to the preferred audio output.
+   */
+  void setPreferredAudioOutput();
 #endif
 
 private:
@@ -242,6 +248,7 @@ private:
 #if QT_VERSION >= 0x060200
   MediaPlaylist* m_mediaPlaylist;
   QAudioOutput* m_audioOutput;
+  QMediaDevices* m_mediaDevices;
 #else
   QMediaPlaylist* m_mediaPlaylist;
 #endif
