@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 04 Jan 2009
  *
- * Copyright (C) 2009-2012  Urs Fleisch
+ * Copyright (C) 2009-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef PICTURELABEL_H
-#define PICTURELABEL_H
+#pragma once
 
 #include <QWidget>
 
@@ -47,7 +46,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~PictureLabel();
+  ~PictureLabel() override;
 
   /**
    * Set picture data.
@@ -66,5 +65,3 @@ private:
   QLabel* m_sizeLabel;
   uint m_pixmapHash;
 };
-
-#endif // PICTURELABEL_H
