@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 23 Sep 2014
  *
- * Copyright (C) 2014-2018  Urs Fleisch
+ * Copyright (C) 2014-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -40,7 +40,7 @@
  */
 class CheckableListModel : public QAbstractProxyModel {
   Q_OBJECT
-  /** Source model, equivalent to the model propery of VisualDataModel. */
+  /** Source model, equivalent to the model property of VisualDataModel. */
   Q_PROPERTY(QObject* sourceModel
              READ sourceModel WRITE setSourceModelObject
              NOTIFY sourceModelChanged)
@@ -64,7 +64,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~CheckableListModel() override = default;
+  ~CheckableListModel() override = default;
 
   /**
    * Get selection model.
@@ -146,36 +146,36 @@ public:
   void setCurrentRow(int row);
 
   /** Set item flags. */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
+  Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /** Get data for a given role. */
-  virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+  QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
 
   /** Set data for a given role. */
-  virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role = Qt::EditRole) override;
+  bool setData(const QModelIndex& index, const QVariant& value,
+               int role = Qt::EditRole) override;
 
   /** Set source model. */
-  virtual void setSourceModel(QAbstractItemModel* srcModel) override;
+  void setSourceModel(QAbstractItemModel* srcModel) override;
 
   /** Get index in model. */
-  virtual QModelIndex index(int row, int column,
-                            const QModelIndex& parent = QModelIndex()) const override;
+  QModelIndex index(int row, int column,
+                    const QModelIndex& parent = QModelIndex()) const override;
 
   /** Get parent model index. */
-  virtual QModelIndex parent(const QModelIndex& child) const override;
+  QModelIndex parent(const QModelIndex& child) const override;
 
   /** Get number of rows under given @a parent. */
-  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+  int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /** Get number of columns under given @a parent. */
-  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+  int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /** Map proxy index to index of source model. */
-  virtual QModelIndex mapToSource(const QModelIndex& proxyIndex) const override;
+  QModelIndex mapToSource(const QModelIndex& proxyIndex) const override;
 
   /** Map index of source model to proxy index. */
-  virtual QModelIndex mapFromSource(const QModelIndex& srcIndex) const override;
+  QModelIndex mapFromSource(const QModelIndex& srcIndex) const override;
 
 signals:
   /** Emitted when source model is changed. */
